==> cockpit-ovirt-0.11.33.tar.gz: cockpit-ovirt-0.11.33/dashboard/src/components/HeSetupFooter.js <==
import React from 'react'

const HeSetupFooter = () => {
    return (
        <div className="he-wizard-footer">
            <div className="container">
                <div className="row he-wizard-footer-content">
                    <div className="col-sm-6">
                        <div className="row">
                            <div className="col-sm-3 he-wizard-footer-header">
                                Getting Started
                            </div>
                            <div className="col-sm-6">
                                <ul className="he-wizard-footer-links">
                                    <li>
                                        <a href="https://ovirt.org/documentation/self-hosted/Self-Hosted_Engine_Guide/" target="_blank">
                                            Installation Guide
                                        </a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div className="col-sm-6">
                        <div className="row">
                            <div className="col-sm-4 he-wizard-footer-header">
                                More Information
                            </div>
                            <div className="col-sm-6">
                                <ul className="he-wizard-footer-links">
                                    <li>
                                        <a href="http://www.ovirt.org/" target="_blank">oVirt Homepage</a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    )
};

export default HeSetupFooter;

==> cockpit-ovirt-0.15.1.tar.gz: cockpit-ovirt-0.15.1/dashboard/src/components/HeSetupFooter.js <==
import React from 'react'

const HeSetupFooter = () => {
    return (
        <div className="he-wizard-footer">
            <div className="container">
                <div className="row he-wizard-footer-content">
                    <div className="col-sm-6">
                        <div className="row">
                            <div className="col-sm-3 he-wizard-footer-header">
                                Getting Started
                            </div>
                            <div className="col-sm-6">
                                <ul className="he-wizard-footer-links">
                                    <li>
                                        <a href="https://ovirt.org/documentation/installing_ovirt_as_a_self-hosted_engine_using_the_cockpit_web_interface/" target="_blank">
                                            Installation Guide
                                        </a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>

                    <div className="col-sm-6">
                        <div className="row">
                            <div className="col-sm-4 he-wizard-footer-header">
                                More Information
                            </div>
                            <div className="col-sm-6">
                                <ul className="he-wizard-footer-links">
                                    <li>
                                        <a href="https://www.ovirt.org/" target="_blank">oVirt Homepage</a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    )
};

export default HeSetupFooter;
